
// 门墩儿招聘
import teacher from './components/recruit/teacher'
import enterprise from './components/recruit/enterprise'
import personal from './components/recruit/personal'
import Layout from '@/layout'
import { setCommonPage } from '@/utils/dealData'

const recruit = [
  {
    path: '/recruit',
    redirect: '/recruitHome'
  },
  {
    path: '/personal', // 不可删 // 个人账号登录时，缺省只能访问个人账号路由和不需要登录，防止用户在地址栏直接输入地址访问其他页面（不可删，permission中用到）
    redirect: '/recruitHome'
  },
  {
    path: '/recruitHome',
    component: Layout,
    children: [
      {
        path: '/recruitHome',
        component: () => import('@/views/recruit/personal/home'),
        name: 'recruitHome',
        meta: {
          title: '首页'
        }
      }
    ]
  },
  {
    path: '/mall',
    component: Layout,
    children: [
      {
        path: '/mall',
        component: () => import('@/views/mall/home/index'),
        name: 'mall',
        meta: {
          title: '门墩儿商城'
        }
      },
      {
        path: '/mall/goodsList',
        component: () => import('@/views/mall/goodsList/index'),
        name: 'goodsList',
        meta: {
          title: '商品列表'
        }
      },
      {
        path: '/mall/confirm_order',
        component: () => import('@/views/mall/components/confirm_order'),
        name: 'confirmOrder',
        meta: {
          title: '购买支付'
        }
      },
      {
        path: '/mall/goodsDetail/:id',
        component: () => import('@/views/mall/components/details.vue'),
        name: 'goodsDetail',
        meta: {
          title: '商品详情'
        }
      },
      {
        path: '/mall/cart',
        component: () => import('@/views/mall/cart/index.vue'),
        name: 'mallCart',
        meta: {
          title: '我的购物车'
        }
      },
      {
        path: '/mall/payOver',
        component: () => import('@/views/mall/payOver/index.vue'),
        name: 'mallPayOver',
        meta: {
          title: '支付成功'
        }
      },
    ]
  },
  {
    path: '/mall/order/detail/:id',
    component: Layout,
    children: [
      {
        path: '/mall/order/detail/:id',
        component: () => import('@/views/recruit/personal/PersonalCenter/tradeOrder/components/detail.vue'),
        name: 'mallOrderDetail',
        meta: {
          title: '商城订单详情'
        }
      }
    ]
  },
  {
    path: '/pointsExchange',
    component: Layout,
    children: [
      {
        path: '/pointsExchange',
        component: () => import('@/views/mall1/index.vue'),
        name: 'pointsExchange',
        meta: {
          title: '门墩儿商城'
        }
      }
    ]
  },
  {
    path: '/about',
    component: Layout,
    children: [
      {
        path: '/about',
        component: () => import('@/views/about/index'),
        name: 'about',
        meta: {
          title: '了解门墩儿'
        }
      }
    ]
  },
  {
    path: '/flame',
    component: Layout,
    children: [
      {
        path: '/flame',
        component: () => import('@/views/flame/index'),
        name: 'flame',
        meta: {
          title: '火苗儿校企'
        }
      }
    ]
  },
  {
    path: '/recruit/personal/position',
    component: Layout,
    name: 'recruit',
    children: [
      {
        path: '/recruit/personal/recommend',
        component: () => import('@/views/recruit/personal/recommend'),
        name: 'recommendedPositions',
        meta: {
          title: '推荐'
        }
      },
      {
        path: '/recruit/personal/position',
        component: () => import('@/views/recruit/personal/position'),
        name: 'recruitPosition',
        meta: {
          title: '职位'
        }
      },
      {
        path: '/recruit/personal/company',
        component: () => import('@/views/recruit/personal/company'),
        name: 'recruitCompany',
        meta: {
          title: '公司'
        }
      },
      {
        path: '/recruit/personal/position/details/:id',
        component: () => import('@/views/recruit/personal/position/components/details'),
        name: 'recruitPositionDetails',
        meta: {
          title: '职位详情'
        }
      }
    ]
  },
  {
    path: '/recruit/personal/company/details/:id',
    component: Layout,
    name: 'companyDetails',
    meta: {
      title: '企业详情'
    },
    children: [
      {
        path: '/recruit/personal/company/details/:id',
        component: () => import('@/views/recruit/personal/companyDetail/index.vue'),
        meta: {
          title: '企业详情'
        },
      }
    ]
  },
  {
    path: '/qualificationCertificate',
    component: Layout,
    children: [
      {
        path: '/qualificationCertificate',
        component: () => import('@/views/common/qualificationCertificate.vue'),
        name: 'QualificationCertificate'
      }
    ]
  },
  {
    path: '/contactUs',
    component: Layout,
    children: [
      {
        path: '/contactUs',
        component: () => import('@/views/recruit/components/contactUs/index.vue'),
        name: 'ContactUs',
        meta: {
          title: '联系我们'
        }
      }
    ]
  },
  {
      path: '/recruit/personal/jobFair',
      component: Layout,
      name: 'personalJobFair',
      meta: {
        title: '招聘会'
      },
      children: [
        {
          path: '/recruit/personal/jobFair',
          component: () => import('@/views/recruit/personal/jobFair/index.vue')
        },
      ]
    },
    {
      path: '/recruit/personal/jobFair/:id',
      component: () => import('@/views/recruit/personal/jobFair/details/index.vue'),
      name: 'jobFairDetails'
    },
    {
      path: '/recruit/personal/jobFair/enterprises/:id',
      component: () => import('@/views/recruit/personal/jobFair/details/enterprises.vue'),
      name: 'jobFairEnterprises'
    },
    {
      path: '/recruit/personal/jobFair/entPosition/:id',
      component: () => import('@/views/recruit/personal/jobFair/details/entJobCard.vue'),
      name: 'jobFairEntPosition'
    },
]


setCommonPage(recruit) // 公共访问路由
setCommonPage(recruit) // 公共访问路由

const routeArray = [
  ...recruit,
  ...enterprise,
  ...teacher,
  ...personal
]
export default routeArray